
## CLI

ctc twap uniswap <pool_address>
ctc twap chainlink <feed>




## Specification
should output nan for times that don't have valid values


## Vs Uniswap
- Uniswap native oracles are useful when all of the following hold:
    - computing the twap value for a single timepoint
    - computing the twap of a single pool non-composite price

